summary refs log tree commit diff
path: root/gnu/packages/perl6.scm
diff options
context:
space:
mode:
Diffstat (limited to 'gnu/packages/perl6.scm')
-rw-r--r--gnu/packages/perl6.scm71
1 files changed, 49 insertions, 22 deletions
diff --git a/gnu/packages/perl6.scm b/gnu/packages/perl6.scm
index 0e0c352892..3dfdeec4f1 100644
--- a/gnu/packages/perl6.scm
+++ b/gnu/packages/perl6.scm
@@ -1,6 +1,7 @@
 ;;; GNU Guix --- Functional package management for GNU
 ;;; Copyright © 2019 Efraim Flashner <efraim@flashner.co.il>
 ;;; Copyright © 2019 Tobias Geerinckx-Rice <me@tobias.gr>
+;;; Copyright © 2022 Paul A. Patience <paul@apatience.com>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -28,6 +29,7 @@
   #:use-module (gnu packages libevent)
   #:use-module (gnu packages libffi)
   #:use-module (gnu packages multiprecision)
+  #:use-module (gnu packages perl)
   #:use-module (gnu packages pkg-config)
   #:use-module (gnu packages tls))
 
@@ -220,48 +222,73 @@ regular expression engine for the virtual machine.")
 (define-public rakudo
   (package
     (name "rakudo")
-    (version "2019.03.1")
+    (version "2022.04")
     (source
      (origin
        (method url-fetch)
-       (uri (string-append "https://rakudo.perl6.org/downloads/rakudo/rakudo-"
-                           version ".tar.gz"))
+       (uri (string-append "https://github.com/rakudo/rakudo/releases/download/"
+                           version "/rakudo-" version ".tar.gz"))
        (sha256
-        (base32
-         "1nllf69v8xr6v3kkj7pmryg11n5m3ajfkr7j72pvhrgnjy8lv3r1"))))
+        (base32 "0x0w5b8g5kna1mlvsli9dqmnwvqalrar3cgpixmyiyvyjb6ah4vy"))
+       (modules '((guix build utils)))
+       (snippet
+        '(delete-file-recursively "3rdparty"))))
     (build-system perl-build-system)
     (arguments
-     '(#:phases
+     `(#:phases
        (modify-phases %standard-phases
-         (add-after 'unpack 'patch-source-date
+         (add-after 'unpack 'remove-calls-to-git
            (lambda _
-             (substitute* "tools/build/gen-version.pl"
-               (("gmtime") "gmtime(0)"))))
+             (invoke "perl" "-ni" "-e" "print if not /^BEGIN {/ .. /^}/"
+                     "Configure.pl")))
+         (add-after 'remove-calls-to-git 'fix-paths
+           (lambda _
+             (substitute* "tools/templates/Makefile-common-macros.in"
+               (("NQP_CONFIG_DIR = .*")
+                (string-append "NQP_CONFIG_DIR = "
+                               (assoc-ref %build-inputs "nqp-configure")
+                               "/lib/perl5/site_perl/"
+                               ,(package-version perl)
+                               "\n")))))
+         ;; These tests pass when run manually.
+         (add-after 'fix-paths 'disable-failing-tests
+           (lambda _
+             (substitute* "t/02-rakudo/repl.t"
+               (("^plan 47;\n") "plan 46;\n"))
+             (invoke "perl" "-ni" "-e"
+                     "printf if not /^    \\(temp %\\*ENV\\)/ .. /^    }/"
+                     "t/02-rakudo/repl.t")
+             (substitute* "t/09-moar/01-profilers.t"
+               (("^plan 12;\n") "plan 10;\n")
+               (("^ok \\$htmlpath\\.IO\\.f, .*") "")
+               (("^ok \\(try \\$htmlpath\\.IO\\.s .*") ""))))
          (add-after 'patch-source-shebangs 'patch-more-shebangs
            (lambda _
-             (substitute* '("tools/build/create-js-runner.pl"
-                            "tools/build/create-moar-runner.p6"
-                            "tools/build/create-jvm-runner.pl"
-                            "src/core/Proc.pm6")
+             (substitute* '("src/core.c/Proc.pm6"
+                            "t/spec/S29-os/system.t"
+                            "tools/build/create-js-runner.pl"
+                            "tools/build/create-jvm-runner.pl")
                (("/bin/sh") (which "sh")))))
          (replace 'configure
            (lambda* (#:key inputs outputs #:allow-other-keys)
              (let ((out (assoc-ref outputs "out"))
                    (nqp (assoc-ref inputs "nqp")))
-               (invoke "perl" "./Configure.pl"
+               (invoke "perl" "Configure.pl"
                        "--backend=moar"
                        "--with-nqp" (string-append nqp "/bin/nqp")
                        "--prefix" out))))
          ;; This is the recommended tool for distro maintainers to install perl6
          ;; modules systemwide.  See: https://github.com/ugexe/zef/issues/117
          (add-after 'install 'install-dist-tool
            (lambda* (#:key outputs #:allow-other-keys)
              (let* ((out (assoc-ref outputs "out"))
                     (dest (string-append out "/share/perl6/tools")))
-               (install-file "tools/install-dist.p6" dest)
-               (substitute* (string-append dest "/install-dist.p6")
-                 (("/usr/bin/env perl6")
-                  (string-append out "/bin/perl6")))))))))
+               (install-file "tools/install-dist.raku" dest)
+               (substitute* (string-append dest "/install-dist.raku")
+                 (("/usr/bin/env raku")
+                  (string-append out "/bin/raku")))))))))
+    (native-inputs
+     (list nqp-configure))
     (inputs
      (list moarvm nqp openssl))
     (home-page "https://rakudo.org/")
@@ -272,9 +299,9 @@ regular expression engine for the virtual machine.")
             (files '("share/perl6/lib"
                      "share/perl6/site/lib"
                      "share/perl6/vendor/lib")))))
-    (synopsis "Perl 6 Compiler")
-    (description "Rakudo Perl is a compiler that implements the Perl 6
-specification and runs on top of several virtual machines.")
+    (synopsis "Raku Compiler")
+    (description "Rakudo is a compiler that implements the Raku specification
+and runs on top of several virtual machines.")
     (license license:artistic2.0)))
 
 (define-public perl6-grammar-debugger
@@ -220,48 +222,73 @@ regular expression engine for the virtual machine.")
                        "--with-nqp" (string-append nqp "/bin/nqp")
                        "--prefix" out))))
-         ;; This is the recommended tool for distro maintainers to install perl6
+         ;; This is the recommended tool for distro maintainers to install Raku
          ;; modules systemwide.  See: https://github.com/ugexe/zef/issues/117
          (add-after 'install 'install-dist-tool